package com.bwie.auth.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.bwie.auth.feign.SysUserRemoteService;
import com.bwie.auth.service.AuthUserService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.response.JwtResponse;
import com.bwie.common.pojo.User;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

/**
 * @ClassName AuthUserServiceImpl
 * @Description 描述
 * @Author Chen
 * @Date 2024/7/23 9:41
 */
@Service
public class AuthUserServiceImpl implements AuthUserService {
    @Autowired
    private SysUserRemoteService remoteService;
    @Autowired
    private BCryptPasswordEncoder bCryptPasswordEncoder;
    @Autowired
    private StringRedisTemplate redisTemplate;
    @Autowired
    private HttpServletRequest request;
    @Override
    public Result login(User user) {
        if (StringUtils.isNull(user.getUserPhone())) {
            return Result.error("请输入手机号");
        }
        if (StringUtils.isNull(user.getUserPwd())){
            return Result.error("请输入密码");
        }
        Result<User> login = remoteService.login(user.getUserPhone());
        User data = login.getData();
        boolean matches = bCryptPasswordEncoder.matches(user.getUserPhone(),data.getUserPwd());
        if (matches) {
            return Result.error("密码错误");
        }
        //登录成功 生成 token
        String string = UUID.randomUUID().toString();
        HashMap<String, Object> map = new HashMap<>();
        map.put(JwtConstants.USER_KEY, string);
        String token = JwtUtils.createToken(map);
        redisTemplate.opsForValue().set(TokenConstants.LOGIN_TOKEN_KEY + string, JSON.toJSONString(data), 15, TimeUnit.MINUTES);
        JwtResponse jwtResponse = new JwtResponse();
        jwtResponse.setToken(token);
        jwtResponse.setExistTime("30MIN");
        return Result.success(jwtResponse);
    }

    /**
     * info
     * @return
     */
    @Override
    public Result info() {
        String token = request.getHeader(TokenConstants.TOKEN);
        String userKey = JwtUtils.getUserKey(token);
        String s = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        User user = JSONObject.parseObject(s, User.class);
        return Result.success(user);
    }
}
