package com.bwie.list.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.pojo.Car;
import com.bwie.common.pojo.Record;
import com.bwie.common.pojo.Type;
import com.bwie.common.pojo.User;
import com.bwie.common.utils.JwtUtils;
import com.bwie.list.mapper.CarMapper;
import com.bwie.list.service.CarService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @ClassName CarServiceImpl
 * @Description 描述
 * @Author Chen
 * @Date 2024/7/23 10:58
 */
@Service
public class CarServiceImpl implements CarService {
    @Autowired
    private CarMapper carMapper;
    @Autowired
    private HttpServletRequest request;
    @Autowired
    private StringRedisTemplate redisTemplate;

    /**
     * 自行车列表
     *
     * @param car
     * @return
     */
    @Override
    public List<Car> list(Car car) {
        return carMapper.list(car);
    }

    /**
     * 类型列表
     *
     * @return
     */
    @Override
    public List<Type> typeList() {
        return carMapper.typeList();
    }

    /**
     * 添加用车记录
     *
     * @param carId
     * @return
     */
    @Override
    public Integer recordAdd(Integer carId) {
//        //用carId获取这条数据
//        Car car = carMapper.selectByCarId(carId);
        //修改状态
        carMapper.updateById(carId);
        //添加自行车记录
        Record record1 = new Record();
        String token = request.getHeader(TokenConstants.TOKEN);
        String userKey = JwtUtils.getUserKey(token);
        String s = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        User user = JSONObject.parseObject(s, User.class);
        record1.setUserId(user.getUserId());
        record1.setCarId(carId);
        Integer add = carMapper.recordAdd(record1);
        return add;
    }

    @Override
    public List<Record> recordList(Record record) {
        return carMapper.recordList(record);
    }

    /**
     * 结束行程
     *
     * @param carNumber
     * @return
     */
    @Override
    public Integer updateByReId(String carNumber) {
        Integer upd = carMapper.updateByReId(carNumber);
        //扣费
        if (upd > 0) {
            //通过编号查
            Record record = carMapper.select(carNumber);
            if (record.getTypeName().equals("入门山地车")) {
//                Record recordOne = carMapper.select(carNumber);
                carMapper.updateMoney(record.getUserId(), record.getRecordMoney());
            } else if (record.getTypeName().equals("入门公路车")) {
                Record recordOne = carMapper.selectOne(carNumber);
                carMapper.updateMoney(recordOne.getUserId(), recordOne.getRecordMoney());
            } else if (record.getTypeName().equals("专业山地车")) {
                Record recordTwo = carMapper.selectTwo(carNumber);
                carMapper.updateMoney(recordTwo.getUserId(), recordTwo.getRecordMoney());
            } else {
                Record recordThree = carMapper.selectThree(carNumber);
                carMapper.updateMoney(recordThree.getUserId(), recordThree.getRecordMoney());
            }
        }
        return upd;
    }

}
